==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d9/db1/spritecache_8cpp.js <==
var spritecache_8cpp =
[
    [ "SpriteCache", "d7/d78/structSpriteCache.html", "d7/d78/structSpriteCache" ],
    [ "MemBlock", "d5/d0b/structMemBlock.html", "d5/d0b/structMemBlock" ],
    [ "SpriteTypeByte", "d9/db1/spritecache_8cpp.html#a3dc8e2cb2bbd791a9f7ae7ac04112016", null ],
    [ "AllocateSpriteCache", "d9/db1/spritecache_8cpp.html#ab87646d9e88fa43f37f2e4453e89bb59", null ],
    [ "AllocSprite", "d9/db1/spritecache_8cpp.html#a683bcfa6ad2fee63bcd8c61dbf166808", null ],
    [ "assert_compile", "d9/db1/spritecache_8cpp.html#ac93a314bfb693ec69bf3205d4bf06e68", null ],
    [ "assert_compile", "d9/db1/spritecache_8cpp.html#acc6c3f75bf10104563aa7060379dd0d3", null ],
    [ "CompactSpriteCache", "d9/db1/spritecache_8cpp.html#ae4be27871fd7bed50f3d671c58004f35", null ],
    [ "DeleteEntryFromSpriteCache", "d9/db1/spritecache_8cpp.html#a0236605793392382a8e5fd81eed51252", null ],
    [ "DeleteEntryFromSpriteCache", "d9/db1/spritecache_8cpp.html#aec891736d07dcf3eff4a819033397cef", null ],
    [ "DupSprite", "d9/db1/spritecache_8cpp.html#ab4efdf6172569bcb0e02a16da4c148f4", null ],
    [ "GetGRFSpriteOffset", "d9/db1/spritecache_8cpp.html#af02e0bb82b3760758d27fa552e6021c5", null ],
    [ "GetMaxSpriteID", "d9/db1/spritecache_8cpp.html#aadd3ca423040ad38fe1e92a2a8e085e5", null ],
    [ "GetOriginFileSlot", "d9/db1/spritecache_8cpp.html#a9ca60b240e70a812ced9b8b8d9df7640", null ],
    [ "GetRawSprite", "d9/db1/spritecache_8cpp.html#a6b9a79cc336747896c172b2e4548c023", null ],
    [ "GetSpriteCache", "d9/db1/spritecache_8cpp.html#a1ff9177b30d8477a52d51f5fd04d7b3a", null ],
    [ "GetSpriteCacheUsage", "d9/db1/spritecache_8cpp.html#a98268124cec6d9e4611b97bbd44005d5", null ],
    [ "GetSpriteCountForSlot", "d9/db1/spritecache_8cpp.html#a32c1a7879f9140da522ad294d28d960c", null ],
    [ "GetSpriteType", "d9/db1/spritecache_8cpp.html#a2342355d91f646c7e90442e80cc755bc", null ],
    [ "GfxClearSpriteCache", "d9/db1/spritecache_8cpp.html#a2bee11539fc236b9c7c41e7e3f9f8718", null ],
    [ "GfxInitSpriteCache", "d9/db1/spritecache_8cpp.html#a39ac29a9b2857edebf6d06c52b1fb4f2", null ],
    [ "GfxInitSpriteMem", "d9/db1/spritecache_8cpp.html#a9e2984c322c1af9978d601195c1726e6", null ],
    [ "HandleInvalidSpriteRequest", "d9/db1/spritecache_8cpp.html#a6ddb62537bbbd2f01fad0f446ae6e132", null ],
    [ "IncreaseSpriteLRU", "d9/db1/spritecache_8cpp.html#a48b487b476b78246967ebcba67b71017", null ],
    [ "IsMapgenSpriteID", "d9/db1/spritecache_8cpp.html#a265340cee7d5c88d74b4aba7885bffc9", null ],
    [ "LoadNextSprite", "d9/db1/spritecache_8cpp.html#a2f691341533798fa8b657a5c53b43f92", null ],
    [ "NextBlock", "d9/db1/spritecache_8cpp.html#a6003d0480ca13a38a0a8d31ae71dc7c8", null ],
    [ "PadSingleSprite", "d9/db1/spritecache_8cpp.html#a596e1e0af2b555a54179129ee2b413f5", null ],
    [ "PadSprites", "d9/db1/spritecache_8cpp.html#aa2f37c0317bd4cdc2f86dd24c5fa37c0", null ],
    [ "ReadGRFSpriteOffsets", "d9/db1/spritecache_8cpp.html#a030ad2f4c3fe0eac43451ac9d77c4abc", null ],
    [ "ReadRecolourSprite", "d9/db1/spritecache_8cpp.html#a078d32a9e320daccba242639ca632e6e", null ],
    [ "ReadSprite", "d9/db1/spritecache_8cpp.html#a8a789dd3d331f787090e20a72d34469a", null ],
    [ "ResizeSpriteIn", "d9/db1/spritecache_8cpp.html#a882e139855e8e015e69d9f647f9ca823", null ],
    [ "ResizeSpriteOut", "d9/db1/spritecache_8cpp.html#ac428831f2f8978756c3d4839f019c3c0", null ],
    [ "ResizeSprites", "d9/db1/spritecache_8cpp.html#a16574bcb00e03ff2fdef17aac27bd0cf", null ],
    [ "SkipSpriteData", "d9/db1/spritecache_8cpp.html#a5719cb4296630c7f63f0b3bbee98eb14", null ],
    [ "SpriteExists", "d9/db1/spritecache_8cpp.html#a4bb556df22ec5ee7231419b9d01b2c41", null ],
    [ "_allocated_sprite_cache_size", "d9/db1/spritecache_8cpp.html#abe76c0d7db20e4e1032d93fc770f41d9", null ],
    [ "_compact_cache_counter", "d9/db1/spritecache_8cpp.html#add21cad7e8f013f6f00240f6d5eb8e38", null ],
    [ "_grf_sprite_offsets", "d9/db1/spritecache_8cpp.html#a5ec31b93b4c34c73a50a1d466941f287", null ],
    [ "_sprite_cache_size", "d9/db1/spritecache_8cpp.html#a6b348b4d01bf19d14241ec2b97c56ad0", null ],
    [ "_sprite_lru_counter", "d9/db1/spritecache_8cpp.html#a39b415a003f29a9bd2d3bf09e4495b5e", null ],
    [ "_spritecache", "d9/db1/spritecache_8cpp.html#aaab6558d17ff283bd4e1747d157ad8f0", null ],
    [ "_spritecache_items", "d9/db1/spritecache_8cpp.html#a65399c8047e2d9e2eccc1e7da76be9e4", null ],
    [ "_spritecache_ptr", "d9/db1/spritecache_8cpp.html#a687187a9a62e2c62778978f23dc2c90e", null ],
    [ "S_FREE_MASK", "d9/db1/spritecache_8cpp.html#aeda6b6da710e95216ea462bc1edff045", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d9/db1/spritecache_8cpp.js <==
var spritecache_8cpp =
[
    [ "SpriteCache", "d7/d78/structSpriteCache.html", "d7/d78/structSpriteCache" ],
    [ "MemBlock", "d5/d0b/structMemBlock.html", "d5/d0b/structMemBlock" ],
    [ "AllocateSpriteCache", "d9/db1/spritecache_8cpp.html#ab87646d9e88fa43f37f2e4453e89bb59", null ],
    [ "AllocSprite", "d9/db1/spritecache_8cpp.html#a683bcfa6ad2fee63bcd8c61dbf166808", null ],
    [ "CompactSpriteCache", "d9/db1/spritecache_8cpp.html#ae4be27871fd7bed50f3d671c58004f35", null ],
    [ "DeleteEntryFromSpriteCache", "d9/db1/spritecache_8cpp.html#aec891736d07dcf3eff4a819033397cef", null ],
    [ "DeleteEntryFromSpriteCache", "d9/db1/spritecache_8cpp.html#a0236605793392382a8e5fd81eed51252", null ],
    [ "DupSprite", "d9/db1/spritecache_8cpp.html#ab4efdf6172569bcb0e02a16da4c148f4", null ],
    [ "GetGRFSpriteOffset", "d9/db1/spritecache_8cpp.html#af02e0bb82b3760758d27fa552e6021c5", null ],
    [ "GetMaxSpriteID", "d9/db1/spritecache_8cpp.html#aadd3ca423040ad38fe1e92a2a8e085e5", null ],
    [ "GetOriginFileSlot", "d9/db1/spritecache_8cpp.html#a9ca60b240e70a812ced9b8b8d9df7640", null ],
    [ "GetRawSprite", "d9/db1/spritecache_8cpp.html#a6b9a79cc336747896c172b2e4548c023", null ],
    [ "GetSpriteCache", "d9/db1/spritecache_8cpp.html#a1ff9177b30d8477a52d51f5fd04d7b3a", null ],
    [ "GetSpriteCacheUsage", "d9/db1/spritecache_8cpp.html#a98268124cec6d9e4611b97bbd44005d5", null ],
    [ "GetSpriteCountForSlot", "d9/db1/spritecache_8cpp.html#a32c1a7879f9140da522ad294d28d960c", null ],
    [ "GetSpriteLocalID", "d9/db1/spritecache_8cpp.html#a137346c6dca9dfbac2b5aa10f701d574", null ],
    [ "GetSpriteType", "d9/db1/spritecache_8cpp.html#a2342355d91f646c7e90442e80cc755bc", null ],
    [ "GfxClearSpriteCache", "d9/db1/spritecache_8cpp.html#a2bee11539fc236b9c7c41e7e3f9f8718", null ],
    [ "GfxInitSpriteCache", "d9/db1/spritecache_8cpp.html#a39ac29a9b2857edebf6d06c52b1fb4f2", null ],
    [ "GfxInitSpriteMem", "d9/db1/spritecache_8cpp.html#a9e2984c322c1af9978d601195c1726e6", null ],
    [ "HandleInvalidSpriteRequest", "d9/db1/spritecache_8cpp.html#a6ddb62537bbbd2f01fad0f446ae6e132", null ],
    [ "IncreaseSpriteLRU", "d9/db1/spritecache_8cpp.html#a48b487b476b78246967ebcba67b71017", null ],
    [ "IsMapgenSpriteID", "d9/db1/spritecache_8cpp.html#a265340cee7d5c88d74b4aba7885bffc9", null ],
    [ "LoadNextSprite", "d9/db1/spritecache_8cpp.html#a2f691341533798fa8b657a5c53b43f92", null ],
    [ "NextBlock", "d9/db1/spritecache_8cpp.html#a6003d0480ca13a38a0a8d31ae71dc7c8", null ],
    [ "PadSingleSprite", "d9/db1/spritecache_8cpp.html#a596e1e0af2b555a54179129ee2b413f5", null ],
    [ "PadSprites", "d9/db1/spritecache_8cpp.html#aa2f37c0317bd4cdc2f86dd24c5fa37c0", null ],
    [ "ReadGRFSpriteOffsets", "d9/db1/spritecache_8cpp.html#a030ad2f4c3fe0eac43451ac9d77c4abc", null ],
    [ "ReadRecolourSprite", "d9/db1/spritecache_8cpp.html#a078d32a9e320daccba242639ca632e6e", null ],
    [ "ReadSprite", "d9/db1/spritecache_8cpp.html#a8a789dd3d331f787090e20a72d34469a", null ],
    [ "ResizeSpriteIn", "d9/db1/spritecache_8cpp.html#a882e139855e8e015e69d9f647f9ca823", null ],
    [ "ResizeSpriteOut", "d9/db1/spritecache_8cpp.html#ac428831f2f8978756c3d4839f019c3c0", null ],
    [ "ResizeSprites", "d9/db1/spritecache_8cpp.html#a16574bcb00e03ff2fdef17aac27bd0cf", null ],
    [ "SkipSpriteData", "d9/db1/spritecache_8cpp.html#a5719cb4296630c7f63f0b3bbee98eb14", null ],
    [ "SpriteExists", "d9/db1/spritecache_8cpp.html#a4bb556df22ec5ee7231419b9d01b2c41", null ],
    [ "_allocated_sprite_cache_size", "d9/db1/spritecache_8cpp.html#abe76c0d7db20e4e1032d93fc770f41d9", null ],
    [ "_compact_cache_counter", "d9/db1/spritecache_8cpp.html#add21cad7e8f013f6f00240f6d5eb8e38", null ],
    [ "_grf_sprite_offsets", "d9/db1/spritecache_8cpp.html#a5ec31b93b4c34c73a50a1d466941f287", null ],
    [ "_sprite_cache_size", "d9/db1/spritecache_8cpp.html#a6b348b4d01bf19d14241ec2b97c56ad0", null ],
    [ "_sprite_lru_counter", "d9/db1/spritecache_8cpp.html#a39b415a003f29a9bd2d3bf09e4495b5e", null ],
    [ "_spritecache", "d9/db1/spritecache_8cpp.html#aaab6558d17ff283bd4e1747d157ad8f0", null ],
    [ "_spritecache_items", "d9/db1/spritecache_8cpp.html#a65399c8047e2d9e2eccc1e7da76be9e4", null ],
    [ "_spritecache_ptr", "d9/db1/spritecache_8cpp.html#a687187a9a62e2c62778978f23dc2c90e", null ],
    [ "S_FREE_MASK", "d9/db1/spritecache_8cpp.html#aeda6b6da710e95216ea462bc1edff045", null ]
];
